======================
threedi-openapi-client
======================


.. image:: https://img.shields.io/pypi/v/threedi-api-client.svg
        :target: https://pypi.python.org/pypi/threedi-api-client

.. image:: https://img.shields.io/travis/nens/threedi_openapi_client.svg
        :target: https://travis-ci.com/nens/threedi-openapi-client


* A Python library for the 3Di API


* Free software: BSD license
* Documentation: https://nens.github.io/threedi-openapi-client


Features
--------

* OOP API interaction
* async support
* ...


Installation
------------

We recommend `pip` to install this package::

    pip install --user threedi-api-client


If async support is required, install as follows::

    pip install --user threedi-api-client[aio]


Usage
-----

Head over to the `documentation`_  for usage eaxmples.

.. _documentation: https://nens.github.io/threedi-openapi-client/


Release
-------

Use any tool you like to create a release (zest.releaser, github,...) that creates a release tag. That will trigger a
github action job called "publish". It will create a wheel and tarball and will updload them to `pypi`_.

.. _pypi: https://pypi.org/project/threedi-api-client/

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
